@@ -14,9 +14,27 @@ pub enum SpecsSource {
     NoValues,
     Error,
     Loading,
-    Network,
     Bootstrap,
     Adapter(String),
+    Network,
+}
+
+const DEFAULT_CONFIG_COMPRESSION_MODE: ConfigCompressionMode = ConfigCompressionMode::Gzip;
+
+#[derive(Clone)]
+pub enum ConfigCompressionMode {
+    Gzip,
+    Dictionary,
+}
+
+impl From<&str> for ConfigCompressionMode {
+    fn from(s: &str) -> Self {
+        match s.to_lowercase().as_str() {
+            "gzip" => ConfigCompressionMode::Gzip,
+            "dictionary" => ConfigCompressionMode::Dictionary,
+            _ => DEFAULT_CONFIG_COMPRESSION_MODE,
+        }
+    }
 }
 
 impl SpecsSource {
@@ -34,8 +52,8 @@ impl SpecsSource {
             "NoValues" => SpecsSource::NoValues,
             "Error" => SpecsSource::Error,
             "Loading" => SpecsSource::Loading,
-            "Network" => SpecsSource::Network,
             "Bootstrap" => SpecsSource::Bootstrap,
+            "Network" => SpecsSource::Network,
             _ => SpecsSource::Error,
         }
     }
@@ -86,6 +104,7 @@ pub struct SpecsUpdate {
     pub data: Vec<u8>,
     pub source: SpecsSource,
     pub received_at: u64,
+    pub source_api: Option<String>,
 }
 
 #[repr(C)]
@@ -95,6 +114,7 @@ pub struct SpecsInfo {
     pub checksum: Option<String>,
     pub zstd_dict_id: Option<String>,
     pub source: SpecsSource,
+    pub source_api: Option<String>,
 }
 
 impl SpecsInfo {
@@ -105,6 +125,7 @@ impl SpecsInfo {
             checksum: None,
             zstd_dict_id: None,
             source: SpecsSource::NoValues,
+            source_api: None,
         }
     }
 
@@ -115,6 +136,7 @@ impl SpecsInfo {
             checksum: None,
             zstd_dict_id: None,
             source: SpecsSource::Error,
+            source_api: None,
         }
     }
 }
